version: '3.6'
services:
    {{ opts.full_name }}:
        image: python:{{ aux.project.minimal_version }}-slim-bullseye
        volumes:
            - {{ aux.docker.project_dir }}:/home/container/workdir:rw
        working_dir: /home/container/workdir
        command: [
            /bin/sh, -c,
            pip install twine; /bin/sh ./devops/scripts/sdist; TWINE_PASSWORD=$CI_JOB_TOKEN TWINE_USERNAME=gitlab-ci-token python -m twine upload --repository-url $CI_API_V4_URL/projects/$CI_PROJECT_ID/packages/pypi dist/*
        ]
